@@ -20,8 +20,10 @@ from aleph_message.models import (
     AlephMessage,
     MessagesResponse,
     MessageType,
+    Payment,
     PostMessage,
 )
+from aleph_message.models.execution.environment import HypervisorType
 from aleph_message.models.execution.program import Encoding
 from aleph_message.status import MessageStatus
 
@@ -42,7 +44,7 @@ class AlephClient(ABC):
         :param address: Address of the owner of the aggregate
         :param key: Key of the aggregate
         """
-        pass
+        raise NotImplementedError("Did you mean to import `AlephHttpClient`?")
 
     @abstractmethod
     async def fetch_aggregates(
@@ -54,7 +56,7 @@ class AlephClient(ABC):
         :param address: Address of the owner of the aggregate
         :param keys: Keys of the aggregates to fetch (Default: all items)
         """
-        pass
+        raise NotImplementedError("Did you mean to import `AlephHttpClient`?")
 
     @abstractmethod
     async def get_posts(
@@ -74,7 +76,7 @@ class AlephClient(ABC):
         :param ignore_invalid_messages: Ignore invalid messages (Default: True)
         :param invalid_messages_log_level: Log level to use for invalid messages (Default: logging.NOTSET)
         """
-        pass
+        raise NotImplementedError("Did you mean to import `AlephHttpClient`?")
 
     async def get_posts_iterator(
         self,
@@ -109,7 +111,7 @@ class AlephClient(ABC):
 
         :param file_hash: The hash of the file to retrieve.
         """
-        pass
+        raise NotImplementedError("Did you mean to import `AlephHttpClient`?")
 
     async def download_file_ipfs(
         self,
@@ -167,7 +169,7 @@ class AlephClient(ABC):
         :param ignore_invalid_messages: Ignore invalid messages (Default: True)
         :param invalid_messages_log_level: Log level to use for invalid messages (Default: logging.NOTSET)
         """
-        pass
+        raise NotImplementedError("Did you mean to import `AlephHttpClient`?")
 
     async def get_messages_iterator(
         self,
@@ -202,7 +204,7 @@ class AlephClient(ABC):
         :param item_hash: Hash of the message to fetch
         :param message_type: Type of message to fetch
         """
-        pass
+        raise NotImplementedError("Did you mean to import `AlephHttpClient`?")
 
     @abstractmethod
     def watch_messages(
@@ -214,7 +216,7 @@ class AlephClient(ABC):
 
         :param message_filter: Filter to apply to the messages
         """
-        pass
+        raise NotImplementedError("Did you mean to import `AlephHttpClient`?")
 
 
 class AuthenticatedAlephClient(AlephClient):
@@ -242,7 +244,9 @@ class AuthenticatedAlephClient(AlephClient):
         :param storage_engine: An optional storage engine to use for the message, if not inlined (Default: "storage")
         :param sync: If true, waits for the message to be processed by the API server (Default: False)
         """
-        pass
+        raise NotImplementedError(
+            "Did you mean to import `AuthenticatedAlephHttpClient`?"
+        )
 
     @abstractmethod
     async def create_aggregate(
@@ -264,7 +268,9 @@ class AuthenticatedAlephClient(AlephClient):
         :param inline: Whether to write content inside the message (Default: True)
         :param sync: If true, waits for the message to be processed by the API server (Default: False)
         """
-        pass
+        raise NotImplementedError(
+            "Did you mean to import `AuthenticatedAlephHttpClient`?"
+        )
 
     @abstractmethod
     async def create_store(
@@ -296,7 +302,9 @@ class AuthenticatedAlephClient(AlephClient):
         :param channel: Channel to post the message to (Default: "TEST")
         :param sync: If true, waits for the message to be processed by the API server (Default: False)
         """
-        pass
+        raise NotImplementedError(
+            "Did you mean to import `AuthenticatedAlephHttpClient`?"
+        )
 
     @abstractmethod
     async def create_program(
@@ -344,7 +352,9 @@ class AuthenticatedAlephClient(AlephClient):
         :param subscriptions: Patterns of aleph.im messages to forward to the program's event receiver
         :param metadata: Metadata to attach to the message
         """
-        pass
+        raise NotImplementedError(
+            "Did you mean to import `AuthenticatedAlephHttpClient`?"
+        )
 
     @abstractmethod
     async def create_instance(
@@ -352,6 +362,7 @@ class AuthenticatedAlephClient(AlephClient):
         rootfs: str,
         rootfs_size: int,
         rootfs_name: str,
+        payment: Optional[Payment] = None,
         environment_variables: Optional[Mapping[str, str]] = None,
         storage_engine: StorageEnum = StorageEnum.storage,
         channel: Optional[str] = None,
@@ -363,18 +374,19 @@ class AuthenticatedAlephClient(AlephClient):
         allow_amend: bool = False,
         internet: bool = True,
         aleph_api: bool = True,
-        encoding: Encoding = Encoding.zip,
+        hypervisor: Optional[HypervisorType] = None,
         volumes: Optional[List[Mapping]] = None,
         volume_persistence: str = "host",
         ssh_keys: Optional[List[str]] = None,
         metadata: Optional[Mapping[str, Any]] = None,
     ) -> Tuple[AlephMessage, MessageStatus]:
         """
-        Post a (create) PROGRAM message.
+        Post a (create) INSTANCE message.
 
         :param rootfs: Root filesystem to use
         :param rootfs_size: Size of root filesystem
         :param rootfs_name: Name of root filesystem
+        :param payment: Payment method used to pay for the instance
         :param environment_variables: Environment variables to pass to the program
         :param storage_engine: Storage engine to use (Default: "storage")
         :param channel: Channel to use (Default: "TEST")
@@ -392,7 +404,9 @@ class AuthenticatedAlephClient(AlephClient):
         :param ssh_keys: SSH keys to authorize access to the VM
         :param metadata: Metadata to attach to the message
         """
-        pass
+        raise NotImplementedError(
+            "Did you mean to import `AuthenticatedAlephHttpClient`?"
+        )
 
     @abstractmethod
     async def forget(
@@ -417,7 +431,9 @@ class AuthenticatedAlephClient(AlephClient):
         :param address: Address to use (Default: account.get_address())
         :param sync: If true, waits for the message to be processed by the API server (Default: False)
         """
-        pass
+        raise NotImplementedError(
+            "Did you mean to import `AuthenticatedAlephHttpClient`?"
+        )
 
     @abstractmethod
     async def submit(
@@ -442,7 +458,9 @@ class AuthenticatedAlephClient(AlephClient):
         :param sync: If true, waits for the message to be processed by the API server (Default: False)
         :param raise_on_rejected: Whether to raise an exception if the message is rejected (Default: True)
         """
-        pass
+        raise NotImplementedError(
+            "Did you mean to import `AuthenticatedAlephHttpClient`?"
+        )
 
     async def ipfs_push(self, content: Mapping) -> str:
         """
