@@ -1,6 +1,7 @@
 import hashlib
 import json
 import logging
+import ssl
 import time
 from pathlib import Path
 from typing import Any, Dict, List, Mapping, NoReturn, Optional, Tuple, Union
@@ -11,6 +12,7 @@ from aleph_message.models import (
     AggregateContent,
     AggregateMessage,
     AlephMessage,
+    Chain,
     ForgetContent,
     ForgetMessage,
     InstanceContent,
@@ -24,9 +26,10 @@ from aleph_message.models import (
     StoreContent,
     StoreMessage,
 )
-from aleph_message.models.execution.base import Encoding
+from aleph_message.models.execution.base import Encoding, Payment, PaymentType
 from aleph_message.models.execution.environment import (
     FunctionEnvironment,
+    HypervisorType,
     MachineResources,
 )
 from aleph_message.models.execution.instance import RootfsVolume
@@ -37,7 +40,7 @@ from aleph_message.status import MessageStatus
 from ..conf import settings
 from ..exceptions import BroadcastError, InsufficientFundsError, InvalidMessageError
 from ..types import Account, StorageEnum
-from ..utils import extended_json_encoder
+from ..utils import extended_json_encoder, parse_volume
 from .abstract import AuthenticatedAlephClient
 from .http import AlephHttpClient
 
@@ -68,16 +71,18 @@ class AuthenticatedAlephHttpClient(AlephHttpClient, AuthenticatedAlephClient):
     def __init__(
         self,
         account: Account,
-        api_server: Optional[str],
+        api_server: Optional[str] = None,
         api_unix_socket: Optional[str] = None,
         allow_unix_sockets: bool = True,
         timeout: Optional[aiohttp.ClientTimeout] = None,
+        ssl_context: Optional[ssl.SSLContext] = None,
     ):
         super().__init__(
             api_server=api_server,
             api_unix_socket=api_unix_socket,
             allow_unix_sockets=allow_unix_sockets,
             timeout=timeout,
+            ssl_context=ssl_context,
         )
         self.account = account
 
@@ -449,9 +454,7 @@ class AuthenticatedAlephHttpClient(AlephHttpClient, AuthenticatedAlephClient):
             # Trigger on HTTP calls.
             triggers = {"http": True, "persistent": persistent}
 
-        volumes: List[MachineVolume] = [
-            MachineVolume.parse_obj(volume) for volume in volumes
-        ]
+        volumes: List[MachineVolume] = [parse_volume(volume) for volume in volumes]
 
         content = ProgramContent(
             type="vm-function",
@@ -478,11 +481,13 @@ class AuthenticatedAlephHttpClient(AlephHttpClient, AuthenticatedAlephClient):
             runtime=FunctionRuntime(
                 ref=runtime,
                 use_latest=True,
-                comment="Official aleph.im runtime"
-                if runtime == settings.DEFAULT_RUNTIME_ID
-                else "",
+                comment=(
+                    "Official aleph.im runtime"
+                    if runtime == settings.DEFAULT_RUNTIME_ID
+                    else ""
+                ),
             ),
-            volumes=[MachineVolume.parse_obj(volume) for volume in volumes],
+            volumes=[parse_volume(volume) for volume in volumes],
             time=time.time(),
             metadata=metadata,
         )
@@ -504,6 +509,7 @@ class AuthenticatedAlephHttpClient(AlephHttpClient, AuthenticatedAlephClient):
         rootfs: str,
         rootfs_size: int,
         rootfs_name: str,
+        payment: Optional[Payment] = None,
         environment_variables: Optional[Mapping[str, str]] = None,
         storage_engine: StorageEnum = StorageEnum.storage,
         channel: Optional[str] = None,
@@ -515,7 +521,7 @@ class AuthenticatedAlephHttpClient(AlephHttpClient, AuthenticatedAlephClient):
         allow_amend: bool = False,
         internet: bool = True,
         aleph_api: bool = True,
-        encoding: Encoding = Encoding.zip,
+        hypervisor: Optional[HypervisorType] = None,
         volumes: Optional[List[Mapping]] = None,
         volume_persistence: str = "host",
         ssh_keys: Optional[List[str]] = None,
@@ -528,6 +534,9 @@ class AuthenticatedAlephHttpClient(AlephHttpClient, AuthenticatedAlephClient):
         vcpus = vcpus or settings.DEFAULT_VM_VCPUS
         timeout_seconds = timeout_seconds or settings.DEFAULT_VM_TIMEOUT
 
+        payment = payment or Payment(chain=Chain.ETH, type=PaymentType.hold)
+        hypervisor = hypervisor or HypervisorType.firecracker
+
         content = InstanceContent(
             address=address,
             allow_amend=allow_amend,
@@ -535,6 +544,7 @@ class AuthenticatedAlephHttpClient(AlephHttpClient, AuthenticatedAlephClient):
                 reproducible=False,
                 internet=internet,
                 aleph_api=aleph_api,
+                hypervisor=hypervisor,
             ),
             variables=environment_variables,
             resources=MachineResources(
@@ -551,14 +561,17 @@ class AuthenticatedAlephHttpClient(AlephHttpClient, AuthenticatedAlephClient):
                 size_mib=rootfs_size,
                 persistence="host",
                 use_latest=True,
-                comment="Official Aleph Debian root filesystem"
-                if rootfs == settings.DEFAULT_RUNTIME_ID
-                else "",
+                comment=(
+                    "Official Aleph Debian root filesystem"
+                    if rootfs == settings.DEFAULT_RUNTIME_ID
+                    else ""
+                ),
             ),
-            volumes=[MachineVolume.parse_obj(volume) for volume in volumes],
+            volumes=[parse_volume(volume) for volume in volumes],
             time=time.time(),
             authorized_keys=ssh_keys,
             metadata=metadata,
+            payment=payment,
         )
         message, status, response = await self.submit(
             content=content.dict(exclude_none=True),
