@@ -1,3 +1,3 @@
-TARGET_NODE = "http://163.172.70.92:4024"
+TARGET_NODE = "https://api1.aleph.im"
 REFERENCE_NODE = "https://api2.aleph.im"
 TEST_CHANNEL = "INTEGRATION_TESTS"
